<?php
function test_assets() {
    wp_enqueue_script( 
		'button', 
		plugin_dir_url( __FILE__ )  . '/button.js', [ 'jquery' ], 
    '1.0', 
    true 
  	);
	wp_localize_script( 'frontend-ajax', 'ajaxurl',
	array(admin_url( 'admin-ajax.php' ))
  	);
}
add_action('csf_enqueue', 'test_assets' );

add_action( 'wp_ajax_test_create_pages', 'test_create_pages' );
add_action( 'wp_ajax_nopriv_test_create_pages', 'test_create_pages' );

function test_create_pages(){
	echo json_encode( maybe_create_pages());
	wp_die();
}

/**
 * Create pages.
 *
 * @param array    $pages   Page.
 * @param int|null $parent Parent post ID.
 * @return void
 * @throws \Exception When creating page fails.
 */
function create_pages( $pages, $parent = null ) {
	foreach ( $pages as $page ) {
		$test_options = get_option( 'test-id' );
		$post = [
			'post_title'     => $page['post_title'],
			'post_name'      => $page['post_title'],
			'post_content'   => $page['post_content'],
			'post_status'    => 'publish',
			'post_type'      => 'page',
			'comment_status' => 'closed',
		];

		if ( isset( $parent ) ) {
			$post['post_parent'] = $parent;
		}

		$result = wp_insert_post( $post, true );

		if ( $result instanceof \WP_Error ) {
			throw new \Exception( $result->get_error_message() );
		}

		if ( isset( $page['post_meta'] ) ) {
			foreach ( $page['post_meta'] as $key => $value ) {
				update_post_meta( $result, $key, $value );
			}
		}

		// c'est ici que l'on peut assigner a chaque field sa nouvelle valeur.
		if ( isset( $page['option_name'] ) ) {
			$test_options[$page['option_name']] = $result;
			update_option( 'test-id', $test_options );
		}

		if ( isset( $page['children'] ) ) {
			create_pages( $page['children'], $result );
		}
	}
}

/**
 * Maybe create pages.
 *
 * @return void
 */
function maybe_create_pages() {
	// if ( ! filter_has_var( INPUT_POST, 'pronamic_pay_create_pages' ) ) {
	// 	return;
	// }

	// if ( ! check_admin_referer( 'pronamic_pay_settings', 'pronamic_pay_nonce' ) ) {
	// 	return;
	// }

	$pages = [
		[
			'post_title'   => __( 'Payment Status', 'wpayo' ),
			'post_name'    => __( 'payment', 'wpayo' ),
			'post_content' => '',
			'post_meta'    => [
				'_yoast_wpseo_meta-robots-noindex' => true,
			],
			'children'     => [
				'completed' => [
					'post_title'   => __( 'Payment completed', 'wpayo' ),
					'post_name'    => __( 'completed', 'wpayo' ),
					'post_content' => sprintf(
						'<p>%s</p>',
						__( 'The payment has been successfully completed.', 'wpayo' )
					),
					'post_meta'    => [
						'_yoast_wpseo_meta-robots-noindex' => true,
					],
					'option_name'  => 'pronamic_pay_completed_page_id',
				],
				'cancel'    => [
					'post_title'   => __( 'Payment cancelled', 'wpayo' ),
					'post_name'    => __( 'cancelled', 'wpayo' ),
					'post_content' => sprintf(
						'<p>%s</p>',
						__( 'You have cancelled the payment.', 'wpayo' )
					),
					'post_meta'    => [
						'_yoast_wpseo_meta-robots-noindex' => true,
					],
					'option_name'  => 'pronamic_pay_cancel_page_id',
				],
				'expired'   => [
					'post_title'   => __( 'Payment expired', 'wpayo' ),
					'post_name'    => __( 'expired', 'wpayo' ),
					'post_content' => sprintf(
						'<p>%s</p>',
						__( 'Your payment session has expired.', 'wpayo' )
					),
					'post_meta'    => [
						'_yoast_wpseo_meta-robots-noindex' => true,
					],
					'option_name'  => 'pronamic_pay_expired_page_id',
				],
				'error'     => [
					'post_title'   => __( 'Payment error', 'wpayo' ),
					'post_name'    => __( 'error', 'wpayo' ),
					'post_content' => sprintf(
						'<p>%s</p>',
						__( 'An error has occurred during payment.', 'wpayo' )
					),
					'post_meta'    => [
						'_yoast_wpseo_meta-robots-noindex' => true,
					],
					'option_name'  => 'pronamic_pay_error_page_id',
				],
				'unknown'   => [
					'post_title'   => __( 'Payment status unknown', 'wpayo' ),
					'post_name'    => __( 'unknown', 'wpayo' ),
					'post_content' => sprintf(
						'<p>%s</p>',
						__( 'The payment status is unknown.', 'wpayo' )
					),
					'post_meta'    => [
						'_yoast_wpseo_meta-robots-noindex' => true,
					],
					'option_name'  => 'pronamic_pay_unknown_page_id',
				],
			],
		],
		[
			'post_title'   => __( 'Subscription Canceled', 'wpayo' ),
			'post_name'    => __( 'subscription', 'wpayo' ),
			'post_content' => sprintf(
				'<p>%s</p>',
				__( 'The subscription has been canceled.', 'wpayo' )
			),
			'post_meta'    => [
				'_yoast_wpseo_meta-robots-noindex' => true,
			],
			'option_name'  => 'wpayo_pay_subscription_canceled_page_id',
		],
	];

	$message = array(
		'message' => 
			__('The default payment status pages are created,
			their respective fields will be updated after a refresh', 'wpayo'),
		'style'   => 'success');

	try {
		create_pages( $pages );
	} catch ( \Exception $e ) {
			$message = array(
				'message' => 
					__('Default payment status pages could not be created.', 'wpayo'),
				'style'   => 'danger');
	}
	return $message;
}
require_once ('admin/classes/setup.class.php' );
if( class_exists( 'CSF' ) ) {

    // Set a unique slug-like ID
    $prefix = 'test-id';
  
    // Create options
      CSF::createOptions( $prefix, array(
      'menu_title' => 'WPayo',
      'menu_slug'  => 'wpayo',
	  'menu_icon'   => 'dashicons-money-alt',
	  'ajax save'  => true, 
    ) );  
    require_once("section-settings.php");	

	add_action( 'admin_menu', 'my_plugin_menu', 100 );
	function my_plugin_menu(){
	
		add_submenu_page(
			'wpayo',
			'Payments',
			'Payments',
			'edit_posts',
			'edit.php?post_type=wpayo_payment',
		);
		add_submenu_page(
			'wpayo',
			'Subscriptions',
			'Subscriptions',
			'edit_posts',
			'edit.php?post_type=wpayo_pay_subscr',
		);
		add_submenu_page(
			'wpayo',
			'Payment Gateway Configurations',
			'Configurations',
			'edit_posts',
			'edit.php?post_type=wpayo_gateway',
		);
	}	
}
?>